<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Storage.Search

Windows Runtime (WinRT) APIs for for the `Windows.Storage.Search` namespace.

This package provides the `winrt.windows.storage.search` module.
